@@ -164,6 +164,12 @@ unsigned long int zgetseed() {
 // Version 5 -- Wrapping the GSL version
 static Ziggurat::GSL::ZigguratGSL gsl;
 
+// [[Rcpp::export]]
+void zsetseedGSL(const uint32_t s) {
+    gsl.setSeed(s);
+    return;
+}
+
 // [[Rcpp::export]]
 Rcpp::NumericVector zrnormGSL(int n) {
     Rcpp::NumericVector x(n);
@@ -235,6 +241,8 @@ Rcpp::NumericVector zrnormR(int n) {
     return x;
 }
 
+// no zsetseedR() as we use set.seed() to seed R's uniform
+
 // see help(RNGind) and help(Random.user) in R
 static double x_;
 extern "C" double *user_norm_rand() {
